@@ -43,6 +43,11 @@ void qpdf_basic_settings(QPDF &q) // LCOV_EXCL_LINE
     q.setLogger(get_pikepdf_logger());
 }
 
+// The holder for QPDF should still be shared_ptr because the Python Pdf.pages accessor
+// needs to keep a reference to the QPDF, since users can do things like:
+//  accessor = pdf.pages
+//  del pdf
+//  accessor[0]
 std::shared_ptr<QPDF> open_pdf(py::object stream,
     std::string password,
     bool hex_password            = false,
@@ -449,7 +454,7 @@ void init_qpdf(py::module_ &m)
         .value("mmap", access_mode_e::access_mmap)
         .value("mmap_only", access_mode_e::access_mmap_only);
 
-    py::class_<QPDF, std::shared_ptr<QPDF>>(
+    py::class_<QPDF, py::smart_holder>(
         m, "Pdf", "In-memory representation of a PDF", py::dynamic_attr())
         .def_static("new",
             []() {
@@ -503,7 +508,8 @@ void init_qpdf(py::module_ &m)
             [](QPDF &q) {
                 py::list warnings;
                 for (auto w : q.getWarnings()) {
-                    warnings.append(w.what());
+                    py::bytes msg_bytes(w.what());
+                    warnings.append(msg_bytes.attr("decode")("utf-8", "replace"));
                 }
                 return warnings;
             })
@@ -606,7 +612,7 @@ void init_qpdf(py::module_ &m)
                     if (e.matches(cls_dependency_error)) {
                         python_warning(
                             "pikepdf is missing some specialized decoders "
-                            "(probably JBIG2) so not all stream contents can be "
+                            "(probably jbig2dec) so not all stream contents can be "
                             "tested.");
                         w.setDecodeLevel(qpdf_dl_generalized);
                         w.write();
@@ -684,6 +690,8 @@ void init_qpdf(py::module_ &m)
                 dh.flattenAnnotations(required, forbidden);
             },
             py::arg("mode") = "all") // class Pdf
+        .def_property_readonly(
+            "acroform", [](QPDF &q) { return QPDFAcroFormDocumentHelper(q); })
         .def_property_readonly(
             "attachments", [](QPDF &q) { return QPDFEmbeddedFileDocumentHelper(q); });
 }
