@@ -3,6 +3,7 @@
 
 from __future__ import annotations
 
+import sys
 import zlib
 from collections.abc import Sequence
 from contextlib import contextmanager
@@ -40,6 +41,16 @@ from pikepdf.models.image import (
     UnsupportedImageTypeError,
 )
 
+if sys.version_info.releaselevel in ('alpha', 'beta'):
+    # When testing a pre-release, we are likely building Pillow from source, and it will
+    # be missing several of its libraries and trigger errors around missing libtiff and
+    # the CMS library. Rather than trying to get a full build of Pillow, just skip these
+    # tests.
+    pytest.skip(
+        "skipping image tests on alpha/beta due to complex Pillow deps",
+        allow_module_level=True,
+    )
+
 # pylint: disable=redefined-outer-name
 
 
@@ -130,6 +141,15 @@ def test_imagemask_colorspace(trivial):
     assert pdfimage.colorspace is None
 
 
+def test_imagemask_decode(trivial):
+    xobj, _ = trivial
+    rawimage = xobj
+    rawimage.ImageMask = True
+    pdfimage = PdfImage(rawimage)
+    assert pdfimage.image_mask
+    assert pdfimage._decode_array == (0.0, 1.0)
+
+
 def test_malformed_palette(trivial):
     xobj, _ = trivial
     rawimage = xobj
